@@ -27,4 +27,17 @@ class AppConfig(BaseSettings):
     LOG_AS_JSON: bool = False
     EXPOSE_PII: bool = False
 
+    # Dockerization specific settings
+    IS_DOCKERIZED: bool = False
+    BUCKET_NAME: str | None = None
+    BUCKET_PREFIX: str | None = None
+    PROJECT_ID: str | None = None
+
+    # Sentry
+    SENTRY_ENABLE: bool = False
+    SENTRY_URL: str | None = None
+    SENTRY_SEND_DEFAULT_PII: bool = True
+    SENTRY_TRACES_SAMPLE_RATE: float = 1.0
+    SENTRY_PROFILES_SAMPLE_RATE: float = 1.0
+
     model_config = SettingsConfigDict(env_file=".env", extra="ignore")
